@@ -1,7 +1,7 @@
 __project_name__ = 'upsies'
 __description__ = 'Media metadata aggregator'
 __homepage__ = 'https://upsies.readthedocs.io'
-__version__ = '2022.02.08'
+__version__ = '2022.03.17'
 __author__ = 'plotski'
 __author_email__ = 'plotski@example.org'
 
@@ -32,9 +32,17 @@ def application_shutdown(config):
 
     from . import utils
 
+    # Maintain maximum cache size
     utils.fs.limit_directory_size(
         path=config['config']['main']['cache_directory'],
         max_total_size=config['config']['main']['max_cache_size'],
     )
 
+    # Remove empty files and directories
+    utils.fs.prune_empty(
+        path=config['config']['main']['cache_directory'],
+        files=True,
+        directories=True,
+    )
+
     utils.get_aioloop().run_until_complete(utils.http.close())
