@@ -21,10 +21,6 @@ class UpsiesError(Exception):
             return NotImplemented
 
 
-class CancelledError(UpsiesError):
-    """User cancelled an operation"""
-
-
 class ConfigError(UpsiesError):
     """Error while reading/writing config file or setting config file option"""
 
@@ -101,7 +97,7 @@ class SceneError(UpsiesError):
 class SceneRenamedError(SceneError):
     """Renamed scene release"""
     def __init__(self, *, original_name, existing_name):
-        super().__init__(f'Release name should be: {original_name}')
+        super().__init__(f'{existing_name} should be named {original_name}')
         self._original_name = original_name
         self._existing_name = existing_name
 
@@ -142,3 +138,13 @@ class SceneMissingInfoError(UpsiesError):
     """Missing information about a file from a scene release"""
     def __init__(self, file_name):
         super().__init__(f'Missing information: {file_name}')
+
+class SceneAbbreviatedFilenameError(UpsiesError):
+    """
+    An abbreviated scene file name (e.g. foo-bar.mkv) was provided
+
+    These contain almost no information and should always be provided via a
+    properly named parent directory.
+    """
+    def __init__(self, file_name):
+        super().__init__(f'Abbreviated scene file name is verboten: {file_name}')
