@@ -2,6 +2,8 @@
 Change or show configuration file options
 """
 
+import textwrap
+
 from .... import constants, defaults, errors, jobs, utils
 from .base import CommandBase
 
@@ -11,10 +13,42 @@ def _make_pretty_option_list():
     for option in defaults.option_paths():
         option_type = defaults.option_type(option)
         option_type_name = option_type.__name__.lower()
-        if option_type_name == 'str':
+        file, section, name = option.split('.', maxsplit=2)
+        default_value = defaults.defaults[file][section][name]
+        text = [f'{option} ({option_type_name})']
+
+        if option_type_name == 'list':
+            if default_value:
+                text.append(f'  Default: {default_value[0]}')
+                for item in default_value[1:]:
+                    text.append(f'           {item}')
+            else:
+                text.append('  Default: <empty>')
+        else:
+            text.append(f'  Default: {default_value}')
+
+        if option_type_name == 'int':
+            option_type_name = 'integer'
+        elif option_type_name == 'str':
             option_type_name = 'string'
-        lines.append(f'{option} ({option_type_name})')
-    return '\n  '.join(lines)
+        elif option_type_name == 'choice':
+            text.append(f'  Choices: {", ".join(default_value.options)}')
+
+        # Add description indented
+        description = getattr(option_type, 'description', '')
+        if description:
+            description_lines = []
+            for paragraph in description.strip().split('\n'):
+                description_lines.extend(
+                    textwrap.wrap(
+                        text=paragraph,
+                        width=72,
+                    )
+                )
+            text.extend('  ' + line for line in description_lines)
+        lines.append('\n  '.join(text))
+
+    return '\n\n  '.join(lines)
 
 
 class set(CommandBase):
@@ -32,8 +66,6 @@ class set(CommandBase):
     given as multiple arguments, they are concatenated with single spaces. In
     the INI file, list items are delimited by one line break and one or more
     spaces (e.g. "\\n    ").
-
-    Bytes values can handle units like "kB", "MB", "GiB", etc.
     """
 
     names = ('set',)
