@@ -248,12 +248,12 @@ class ReleaseName(collections.abc.Mapping):
     @_translated_property
     def title_with_aka_and_year(self):
         """
-        Combination of :attr:`title`, :attr:`title_aka` and :attr:`year`
+        Combination of :attr:`title_with_aka` with :attr:`country` and :attr:`year`
+        if appropriate
 
         If :attr:`year_required` is `True`, :attr:`year` is appended.
-        If :attr:`country_required` is `True`, :attr:`country` is appended.
 
-        :attr:`title_aka` is appended if it is truthy.
+        If :attr:`country_required` is `True`, :attr:`country` is appended.
         """
         title = [self.title_with_aka]
         if self.country_required:
@@ -265,12 +265,12 @@ class ReleaseName(collections.abc.Mapping):
     @_translated_property
     def year(self):
         """
-        Release year or "UNKNOWN_YEAR" for movies, empty string for series unless
-        :attr:`year_required` is set
+        Release year or "UNKNOWN_YEAR" if :attr:`year_required` is set, empty string
+        otherwise
 
         See also :meth:`fetch_info`.
         """
-        if self.type is ReleaseType.movie or self.year_required:
+        if self.year_required:
             return self._info.get('year') or 'UNKNOWN_YEAR'
         else:
             return self._info.get('year') or ''
@@ -384,6 +384,24 @@ class ReleaseName(collections.abc.Mapping):
     def episode_title(self, value):
         self._info['episode_title'] = str(value)
 
+    @_translated_property
+    def date(self):
+        """
+        Date (YYYY-MM-DD)
+
+        For episodes, this should be the air date or an empty string.
+
+        For anything that isn't an episode, this is an empty string.
+        """
+        if self.type is ReleaseType.episode:
+            return self._info.get('date') or ''
+        else:
+            return ''
+
+    @date.setter
+    def date(self, value):
+        self._info['date'] = str(value)
+
     @_translated_property
     def service(self):
         """Streaming service abbreviation (e.g. "AMZN", "NF") or empty string"""
@@ -748,7 +766,10 @@ class ReleaseName(collections.abc.Mapping):
         parts = [self.title_with_aka_and_year]
 
         if self.type in (ReleaseType.season, ReleaseType.episode):
-            parts.append(str(self.episodes))
+            if self.date:
+                parts.append(self.date)
+            else:
+                parts.append(str(self.episodes))
 
         parts.append(self.resolution)
 
@@ -793,6 +814,7 @@ class ReleaseInfo(collections.abc.MutableMapping):
       - ``year``
       - ``episodes`` (:class:`~.Episodes` instance)
       - ``episode_title``
+      - ``date``
       - ``edition`` (:class:`list` of "Extended", "Uncut", etc)
       - ``resolution``
       - ``service`` (Streaming service abbreviation)
@@ -889,8 +911,7 @@ class ReleaseInfo(collections.abc.MutableMapping):
             guess['episodes'] = Episodes.from_string(''.join(string))
 
         # If we got an abbreviated file name (e.g. "group-titles01e02.mkv"),
-        # guessit can't (and shouldn't) handle it. Try to find episode
-        # information in it.
+        # guessit can't handle it. Try to find episode information in it.
         if guess['episodes']:
             episodes_string = str(guess['episodes'])
             if (
@@ -912,11 +933,17 @@ class ReleaseInfo(collections.abc.MutableMapping):
         return _guessit.default_api.advanced_config
 
     def _get_type(self):
-        # guessit doesn't differentiate between episodes and season packs.
-        # Check if at least one episode is specified.
-        if self['episodes']:
+        if self['date']:
+            # We interpret a date as an air date, which should mean it's an
+            # episode.
+            return ReleaseType.episode
+
+        elif self['episodes']:
+            # guessit doesn't differentiate between episodes and season packs.
+            # Does any season specify an episode?
             if any(episodes for episodes in self['episodes'].values()):
                 return ReleaseType.episode
+            # No single episode means it's one or more season packs.
             else:
                 return ReleaseType.season
         else:
@@ -1035,6 +1062,9 @@ class ReleaseInfo(collections.abc.MutableMapping):
     }
     _remastered_regex = re.compile(rf'(?:{DELIM}|^)((?i:4k{DELIM}+|)(?i:remaster(?:ed|)|restored))(?:{DELIM}|$)')
 
+    def _get_date(self):
+        return _as_string(self._guess.get('date', ''))
+
     def _get_edition(self):
         edition = _as_list(self._guess.get('edition'))
         for edition_fixed, regex in self._edition_translation.items():
